@@ -2,9 +2,9 @@ use strict;
 use warnings;
 package Dist::Zilla::Plugin::PromptIfStale;
 {
-  $Dist::Zilla::Plugin::PromptIfStale::VERSION = '0.001';
+  $Dist::Zilla::Plugin::PromptIfStale::VERSION = '0.002';
 }
-# git description: 0142f81
+# git description: v0.001-6-g8df9978
 
 BEGIN {
   $Dist::Zilla::Plugin::PromptIfStale::AUTHORITY = 'cpan:ETHER';
@@ -21,13 +21,18 @@ use MooseX::Types::LoadableClass 'LoadableClass';
 use List::MoreUtils 'uniq';
 use Module::Runtime 'use_module';
 use version;
+use Path::Tiny;
+use Cwd;
 use HTTP::Tiny;
 use Encode;
 use JSON;
 use namespace::autoclean;
 
 sub mvp_multivalue_args { 'modules' }
-sub mvp_aliases { { module => 'modules' } }
+sub mvp_aliases { {
+    module => 'modules',
+    check_all => 'check_all_plugins',
+} }
 
 has phase => (
     is => 'ro',
@@ -43,7 +48,7 @@ has modules => (
     default => sub { [] },
 );
 
-has check_all => (
+has check_all_plugins => (
     is => 'ro', isa => Bool,
     default => 0,
 );
@@ -64,29 +69,35 @@ sub check_modules
 {
     my $self = shift;
 
-    my @modules = $self->check_all
+    my @modules = $self->check_all_plugins
         ? uniq map { blessed $_ } @{ $self->zilla->plugins }
         : $self->modules;
 
     foreach my $module (@modules)
     {
-        my $indexed_version = $self->_indexed_version($module);
-        my $local_version = version->parse(use_module($module)->VERSION);
+        # ignore modules in the dist currently being built
+        (my $file = $module) =~ s{::}{/}g;
+        $file .= '.pm';
+        $self->log_debug($module . ' provided locally; skipping version check'), next
+            unless path($INC{$file})->relative(getcwd) =~ m/^\.\./;
 
         $self->log_debug('comparing indexed vs. local version for ' . $module);
 
+        my $indexed_version = $self->_indexed_version($module);
+        my $local_version = version->parse(use_module($module)->VERSION);
+
         if (defined $indexed_version
             and defined $local_version
             and $local_version < $indexed_version)
         {
-            my $abort = $self->zilla->chrome->prompt_yn(
+            my $continue = $self->zilla->chrome->prompt_yn(
                 'Indexed version of ' . $module . ' is ' . $indexed_version
                     . ' but you only have ' . $local_version
-                    . ' installed. Abort the build?',
-                { default => 1 },
+                    . ' installed. Continue anyway?',
+                { default => 0 },
             );
 
-            $self->log_fatal('Aborting build') if $abort;
+            $self->log_fatal('Aborting build') if not $continue;
         }
     }
 }
@@ -97,15 +108,15 @@ sub _indexed_version
     my ($self, $module) = @_;
 
     my $res = HTTP::Tiny->new->get("http://cpanidx.org/cpanidx/json/mod/$module");
-    return (0, 'index could not be queried?') if not $res->{success};
+    $self->log_debug('could not query the index?'), return undef if not $res->{success};
 
     # JSON wants UTF-8 bytestreams, so we need to re-encode no matter what
     # encoding we got. -- rjbs, 2011-08-18 (in Dist::Zilla)
     my $json_octets = Encode::encode_utf8($res->{content});
     my $payload = JSON::->new->decode($json_octets);
 
-    return undef unless \@$payload;
-    return undef if not defined $payload->[0]{mod_vers};
+    $self->log_debug('invalid payload returned?'), return undef unless $payload;
+    $self->log_debug($module . ' not indexed'), return undef if not defined $payload->[0]{mod_vers};
     version->parse($payload->[0]{mod_vers});
 }
 
@@ -125,7 +136,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build time if modules are out of d
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -137,8 +148,9 @@ In your F<dist.ini>:
     module = Dist::Zilla::PluginBundle::Author::ME
 
 or:
+
     [PromptIfStale]
-    check_all = 1
+    check_all_plugins = 1
 
 =head1 DESCRIPTION
 
